﻿import es
import gamethread
import keymenulib
import langlib
import playerlib
import popuplib

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2010/language/"
common = langlib.Strings(lang_dir + "common.ini")
messages = langlib.Strings(lang_dir + "admin/messages_admin.ini")

# ******************** Load ********************
def load():
	es.keygroupcreate("sm_keygroup_set")

	create_popup()

	es.load("soccer_mod_2010/manager")

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings(lang_dir + "admin/popup_admin.ini")

	popup = popuplib.create("sm_popup_admin")

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")

	number = 0

	if es.ServerVar("sm_module_match_on") == 1:
		number += 1
		popup.addline("->%s. %s" % (number, text("match")))
		popup.select(number, match)

	if es.ServerVar("sm_module_cap_on") == 1:
		number += 1
		popup.addline("->%s. %s" % (number, text("cap")))
		popup.select(number, cap)

	if es.ServerVar("sm_module_referee_on") == 1:
		number += 1
		popup.addline("->%s. %s" % (number, text("referee")))
		popup.select(number, referee)

	if es.ServerVar("sm_module_training_on") == 1:
		number += 1
		popup.addline("->%s. %s" % (number, text("training")))
		popup.select(number, training)

	if es.ServerVar("sm_module_skins_on") == 1:
		number += 1
		popup.addline("->%s. %s" % (number, text("skins")))
		popup.select(number, skins)

	number += 1
	popup.addline("->%s. %s" % (number, text("map")))
	popup.select(number, change_map_select)

	number += 1
	popup.addline("->%s. %s" % (number, text("settings")))
	popup.select(number, settings)

	number += 1
	popup.addline("->%s. %s" % (number, text("manager")))
	popup.select(number, manager)

	popup.addline(" ")
	popup.addline("0. %s" % (common("close")))

	number += 1
	while number < 10:
		popup.submenu(number, "sm_popup_admin")
		number += 1

# ******************** Events ********************
def es_map_start(event_var):
	es.keygroupdelete("sm_keygroup_set")
	es.keygroupcreate("sm_keygroup_set")

def player_disconnect(event_var):
	name = "sm_popup_%s" % (event_var["userid"])
	if popuplib.exists(name):
		popuplib.delete(name)

	name = "sm_keymenu_%s" % (event_var["userid"])
	if keymenulib.exists(name):
		keymenulib.delete(name)

# ******************** Commands ********************
def cmd_admin():
	tokens = {}
	userid = es.getcmduserid()
	player = playerlib.getPlayer(userid)

	if es.exists("key", "soccer_mod_admins", player.steamid) == 1:
		popuplib.send("sm_popup_admin", userid)
	else:
		es.tell(userid, "#green", messages("admin", tokens, player.get("lang")))

# ******************** Popup choices ********************
def match(userid, choice, popupid):
	admin_popup_check("match", userid)

def cap(userid, choice, popupid):
	admin_popup_check("cap", userid)

def referee(userid, choice, popupid):
	admin_popup_check("referee", userid)

def training(userid, choice, popupid):
	admin_popup_check("training", userid)

def skins(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("soccer_mod_allowed") == 1:
		popuplib.send("sm_popup_admin_skins", userid)
	else:
		es.tell(userid, "#green", common("not_allowed", tokens, player.get("lang")))
		popuplib.send("sm_popup_admin", userid)

def change_map_select(userid, choice, popupid):
	name = "sm_keymenu_%s" % (userid)
	if keymenulib.exists(name):
		keymenulib.delete(name)

	tokens = {}
	player = playerlib.getPlayer(userid)

	keymenu = keymenulib.create(name, "target", change_map_choice, "soccer_mod_maps", "#key", "#key", messages("change_map", tokens, player.get("lang")))
	keymenu.backmenu("sm_popup_admin")
	keymenulib.send(name, userid)

def settings(userid, choice, popupid):
	admin_popup_check("settings", userid)

def manager(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if int(es.keygetvalue("soccer_mod_admins", player.steamid, "manager")) == 1:
		popuplib.send("sm_popup_admin_manager", userid)
	else:
		es.tell(userid, "#green", messages("manager", tokens, player.get("lang")))
		popuplib.send("sm_popup_admin", userid)

# ******************** Keymenu choices ********************
def change_map_choice(userid, choice, keymenuname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("match") == 0:
		if es.exists("map", choice) == 1:
			tokens["name"] = player.name
			tokens["map"] = choice
			lang_msg("changed_map", tokens)

			gamethread.delayed(3, es.server.queuecmd, ("changelevel %s" % (choice)))
		else:
			tokens["name"] = choice
			es.tell(userid, "#green", messages("map_no_exist", tokens, player.get("lang")))

			popuplib.send("sm_popup_admin", userid)
	else:
		es.tell(userid, "#green", messages("no_change_map_match", tokens, player.get("lang")))
		popuplib.send("sm_popup_admin", userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	for player in playerlib.getPlayerList("#human"):
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def admin_popup_check(module, userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("soccer_mod_allowed") == 1:
		if int(es.keygetvalue("soccer_mod_admins", player.steamid, module)) == 1:
			popuplib.send("sm_popup_admin_%s" % (module), userid)
		else:
			es.tell(userid, "#green", messages(module, tokens, player.get("lang")))
			popuplib.send("sm_popup_admin", userid)
	else:
		es.tell(userid, "#green", common("not_allowed", tokens, player.get("lang")))
		popuplib.send("sm_popup_admin", userid)

# ******************** Unload ********************
def unload():
	es.keygroupdelete("sm_keygroup_set")

	popuplib.delete("sm_popup_admin")

	es.unload("soccer_mod_2010/manager")