﻿import es
import gamethread
import keymenulib
import keyvalues
import langlib
import playerlib
import popuplib

common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/manager/messages_manager.ini")

# ******************** Load ********************
def load():
	es.keygroupload("soccer_mod_admins", "soccer_mod")
	es.keygroupload("soccer_mod_maps", "soccer_mod")

	create_popup()
	es.addons.registerSayFilter(sayFilter)

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/manager/popup_admin_manager.ini")

	popup = popuplib.create("sm_popup_admin_manager")

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")
	popup.addline("->1. %s" % (text("add_map")))
	popup.addline("->2. %s" % (text("remove_map")))
	popup.addline("->3. %s" % (text("add_admin")))
	popup.addline("->4. %s" % (text("edit_admin")))
	popup.addline("->5. %s" % (text("remove_admin")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("0. %s" % (common("close")))

	popup.select(1, select_add_map)
	popup.select(2, select_remove_map)
	popup.select(3, select_add_admin)
	popup.select(4, select_edit_admin)
	popup.select(5, select_remove_admin)
	popup.submenu(6, "sm_popup_admin_manager")
	popup.submenu(7, "sm_popup_admin_manager")
	popup.submenu(8, "sm_popup_admin_manager")
	popup.submenu(9, "sm_popup_admin")

# ******************** Events ********************
def sayFilter(userid, text, teamonly):
	steamid = es.getplayersteamid(userid)

	if es.exists("key", "sm_keygroup_set", steamid) == 1:
		text = text.strip('"')
		type = es.keygetvalue("sm_keygroup_set", steamid, "setting_type")
		if type == "manager_map_add":
			add_map(text, userid, steamid)
			return (0, None, 0)
		elif type == "manager_admin_add_name":
			add_admin_name(text, userid, steamid)
			return (0, None, 0)
		elif type == "manager_admin_add_steamid":
			add_admin_steamid(text, userid, steamid)
			return (0, None, 0)
		elif type == "manager_admin_edit_name":
			edit_admin_name(text, userid, steamid)
			return (0, None, 0)
		elif type == "manager_admin_edit_steamid":
			edit_admin_steamid(text, userid, steamid)
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

# ******************** Add map ********************
def select_add_map(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
		es.keycreate("sm_keygroup_set", player.steamid)

	es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "manager_map_add")

	es.tell(userid, "#green", messages("add_map", tokens, player.get("lang")))

def add_map(text, userid, steamid):
	if text != "!cancel":
		tokens = {}
		tokens["name"] = text

		player = playerlib.getPlayer(userid)
		if es.exists("key", "soccer_mod_maps", text) == 0:
			if es.exists("map", text) == 1:
				es.keycreate("soccer_mod_maps", text)
				es.keysetvalue("soccer_mod_maps", text, "soccer_mod", 1)

				es.server.cmd("keygroupsort soccer_mod_maps soccer_mod_maps asc #alpha")
				es.keygroupsave("soccer_mod_maps", "soccer_mod")

				es.tell(userid, "#green", messages("map_added", tokens, player.get("lang")))

				if es.ServerVar("eventscripts_currentmap") == text:
					if es.ServerVar("soccer_mod_allowed") == 0:
						lang_msg("map_restart", tokens)

						gamethread.delayed(3, es.server.queuecmd, ("changelevel %s" % (text)))
			else:
				es.tell(userid, "#green", messages("map_no_exist", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("map_exist", tokens, player.get("lang")))

	clear_key(userid, steamid)

# ******************** Remove map ********************
def select_remove_map(userid, choice, popupid):
	name = "sm_keymenu_%s" % (userid)
	if keymenulib.exists(name):
		keymenulib.delete(name)

	tokens = {}
	player = playerlib.getPlayer(userid)

	keymenu = keymenulib.create(name, "target", remove_map, "soccer_mod_maps", "#key", "#key", messages("remove_map", tokens, player.get("lang")))
	keymenu.backmenu("sm_popup_admin_manager")
	keymenulib.send(name, userid)

def remove_map(userid, choice, keymenuname):
	tokens = {}
	tokens["name"] = choice
	player = playerlib.getPlayer(userid)

	number = 0
	for map in keyvalues.getKeyGroup("soccer_mod_maps"):
		number += 1

	if number > 1:
		if es.exists("key", "soccer_mod_maps", choice) == 1:
			es.keydelete("soccer_mod_maps", choice)
			es.keygroupsave("soccer_mod_maps", "soccer_mod")

			es.tell(userid, "#green", messages("map_removed", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("remove_map_no_exist", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("1_map", tokens, player.get("lang")))

	popuplib.send("sm_popup_admin_manager", userid)

# ******************** Add admin ********************
def select_add_admin(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
		es.keycreate("sm_keygroup_set", player.steamid)

	es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "manager_admin_add_name")

	es.tell(userid, "#green", messages("add_admin_name", tokens, player.get("lang")))

def add_admin_name(text, userid, steamid):
	if text != "!cancel":
		es.keysetvalue("sm_keygroup_set", steamid, "setting_type", "manager_admin_add_steamid")
		es.keysetvalue("sm_keygroup_set", steamid, "name", text)

		tokens = {}
		player = playerlib.getPlayer(userid)
		es.tell(userid, "#green", messages("add_admin_steamid", tokens, player.get("lang")))
	else:
		clear_key(userid, steamid)

def add_admin_steamid(text, userid, steamid):
	if text != "!cancel":
		name = es.keygetvalue("sm_keygroup_set", steamid, "name")

		tokens = {}
		tokens["name"] = name
		player = playerlib.getPlayer(userid)

		if es.exists("key", "soccer_mod_admins", text) == 0:
			es.keycreate("soccer_mod_admins", text)
			es.keysetvalue("soccer_mod_admins", text, "name", name)
			es.keysetvalue("soccer_mod_admins", text, "match", 0)
			es.keysetvalue("soccer_mod_admins", text, "cap", 0)
			es.keysetvalue("soccer_mod_admins", text, "referee", 0)
			es.keysetvalue("soccer_mod_admins", text, "training", 0)
			es.keysetvalue("soccer_mod_admins", text, "settings", 0)
			es.keysetvalue("soccer_mod_admins", text, "manager", 0)

			es.server.cmd("keygroupsort soccer_mod_admins name asc #alpha")
			es.keygroupsave("soccer_mod_admins", "soccer_mod")

			es.tell(userid, "#green", messages("admin_added", tokens, player.get("lang")))

			es.keydelete("sm_keygroup_set", steamid)
			es.keycreate("sm_keygroup_set", steamid)
			es.keysetvalue("sm_keygroup_set", steamid, "edit", text)

			name = "sm_popup_%s" % (userid)
			create_popup_edit(name, text)
			popuplib.send(name, userid)
		else:
			es.tell(userid, "#green", messages("add_admin_exist", tokens, player.get("lang")))
			clear_key(userid, steamid)
	else:
		clear_key(userid, steamid)

# ******************** Edit admin ********************
def select_edit_admin(userid, choice, popupid):
	name = "sm_keymenu_%s" % (userid)
	if keymenulib.exists(name):
		keymenulib.delete(name)

	tokens = {}
	player = playerlib.getPlayer(userid)

	keymenu = keymenulib.create(name, "target", edit_admin, "soccer_mod_admins", "#keyvalue name", "#key", messages("edit_admin", tokens, player.get("lang")))
	keymenu.backmenu("sm_popup_admin_manager")
	keymenulib.send(name, userid)

def edit_admin(userid, choice, keymenuname):
	if es.exists("key", "soccer_mod_admins", choice) == 1:
		steamid = es.getplayersteamid(userid)

		if es.exists("key", "sm_keygroup_set", steamid) == 0:
			es.keycreate("sm_keygroup_set", steamid)

		es.keysetvalue("sm_keygroup_set", steamid, "edit", choice)

		name = "sm_popup_%s" % (userid)
		create_popup_edit(name, choice)
		popuplib.send(name, userid)
	else:
		tokens = {}
		tokens["name"] = choice
		player = playerlib.getPlayer(userid)
		es.tell(userid, "#green", messages("admin_no_exist", tokens, player.get("lang")))
		popuplib.send("sm_popup_admin_manager", userid)

def create_popup_edit(name, steamid):
	if popuplib.exists(name):
		popuplib.delete(name)

	text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/manager/popup_admin_manager_admin_edit.ini")

	popup = popuplib.create(name)

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")
	popup.addline("->1. %s: %s" % (text("name"), es.keygetvalue("soccer_mod_admins", steamid, "name")))
	popup.addline("->2. %s: %s" % (text("steamid"), steamid))

	if int(es.keygetvalue("soccer_mod_admins", steamid, "match")) == 1:
		line = "->3. %s: %s" % (text("match"), text("yes"))
	else:
		line = "->3. %s: %s" % (text("match"), text("no"))
	popup.addline(line)

	if int(es.keygetvalue("soccer_mod_admins", steamid, "cap")) == 1:
		line = "->4. %s: %s" % (text("cap"), text("yes"))
	else:
		line = "->4. %s: %s" % (text("cap"), text("no"))
	popup.addline(line)

	if int(es.keygetvalue("soccer_mod_admins", steamid, "referee")) == 1:
		line = "->5. %s: %s" % (text("referee"), text("yes"))
	else:
		line = "->5. %s: %s" % (text("referee"), text("no"))
	popup.addline(line)

	if int(es.keygetvalue("soccer_mod_admins", steamid, "training")) == 1:
		line = "->6. %s: %s" % (text("training"), text("yes"))
	else:
		line = "->6. %s: %s" % (text("training"), text("no"))
	popup.addline(line)

	if int(es.keygetvalue("soccer_mod_admins", steamid, "settings")) == 1:
		line = "->7. %s: %s" % (text("settings"), text("yes"))
	else:
		line = "->7. %s: %s" % (text("settings"), text("no"))
	popup.addline(line)

	if int(es.keygetvalue("soccer_mod_admins", steamid, "manager")) == 1:
		line = "->8. %s: %s" % (text("manager"), text("yes"))
	else:
		line = "->8. %s: %s" % (text("manager"), text("no"))
	popup.addline(line)

	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("0. %s" % (common("close")))

	popup.select(1, select_edit_admin_name)
	popup.select(2, select_edit_admin_steamid)
	popup.select(3, edit_admin_access)
	popup.select(4, edit_admin_access)
	popup.select(5, edit_admin_access)
	popup.select(6, edit_admin_access)
	popup.select(7, edit_admin_access)
	popup.select(8, edit_admin_access)
	popup.submenu(9, "sm_popup_admin_manager")

def select_edit_admin_name(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
		es.keycreate("sm_keygroup_set", player.steamid)

	es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "manager_admin_edit_name")

	es.tell(userid, "#green", messages("add_admin_name", tokens, player.get("lang")))

def edit_admin_name(text, userid, steamid):
	user_steamid = es.getplayersteamid(userid)
	steamid = es.keygetvalue("sm_keygroup_set", user_steamid, "edit")

	if text != "!cancel":
		es.keysetvalue("soccer_mod_admins", steamid, "name", text)

		es.server.cmd("keygroupsort soccer_mod_admins name asc #alpha")
		es.keygroupsave("soccer_mod_admins", "soccer_mod")

		tokens = {}
		tokens["name"] = text
		player = playerlib.getPlayer(userid)
		es.tell(userid, "#green", messages("name_changed", tokens, player.get("lang")))

	es.keydelete("sm_keygroup_set", user_steamid)
	es.keycreate("sm_keygroup_set", user_steamid)
	es.keysetvalue("sm_keygroup_set", user_steamid, "edit", steamid)

	name = "sm_popup_%s" % (userid)
	create_popup_edit(name, steamid)
	popuplib.send(name, userid)

def select_edit_admin_steamid(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
		es.keycreate("sm_keygroup_set", player.steamid)

	es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "manager_admin_edit_steamid")

	es.tell(userid, "#green", messages("add_admin_steamid", tokens, player.get("lang")))

def edit_admin_steamid(text, userid, steamid):
	user_steamid = es.getplayersteamid(userid)
	steamid = es.keygetvalue("sm_keygroup_set", user_steamid, "edit")

	if text != "!cancel":
		tokens = {}
		tokens["steamid"] = text
		tokens["name"] = text

		player = playerlib.getPlayer(userid)

		if es.exists("key", "soccer_mod_admins", text) == 0:
			es.keycreate("soccer_mod_admins", text)

			es.keysetvalue("soccer_mod_admins", text, "name", es.keygetvalue("soccer_mod_admins", steamid, "name"))
			es.keysetvalue("soccer_mod_admins", text, "cap", es.keygetvalue("soccer_mod_admins", steamid, "cap"))
			es.keysetvalue("soccer_mod_admins", text, "match", es.keygetvalue("soccer_mod_admins", steamid, "match"))
			es.keysetvalue("soccer_mod_admins", text, "referee", es.keygetvalue("soccer_mod_admins", steamid, "referee"))
			es.keysetvalue("soccer_mod_admins", text, "training", es.keygetvalue("soccer_mod_admins", steamid, "training"))
			es.keysetvalue("soccer_mod_admins", text, "settings", es.keygetvalue("soccer_mod_admins", steamid, "settings"))
			es.keysetvalue("soccer_mod_admins", text, "manager", es.keygetvalue("soccer_mod_admins", steamid, "manager"))

			es.keydelete("soccer_mod_admins", steamid)

			es.keygroupsave("soccer_mod_admins", "soccer_mod")

			es.keysetvalue("sm_keygroup_set", user_steamid, "edit", text)
			steamid = text

			es.tell(userid, "#green", messages("steamid_changed", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("add_admin_exist", tokens, player.get("lang")))

	es.keydelete("sm_keygroup_set", user_steamid)
	es.keycreate("sm_keygroup_set", user_steamid)
	es.keysetvalue("sm_keygroup_set", user_steamid, "edit", steamid)

	name = "sm_popup_%s" % (userid)
	create_popup_edit(name, steamid)
	popuplib.send(name, userid)

def edit_admin_access(userid, choice, popupid):
	steamid = es.keygetvalue("sm_keygroup_set", es.getplayersteamid(userid), "edit")
	if choice == 3:
		if int(es.keygetvalue("soccer_mod_admins", steamid, "match")) == 1:
			es.keysetvalue("soccer_mod_admins", steamid, "match", 0)
		else:
			es.keysetvalue("soccer_mod_admins", steamid, "match", 1)
	elif choice == 4:
		if int(es.keygetvalue("soccer_mod_admins", steamid, "cap")) == 1:
			es.keysetvalue("soccer_mod_admins", steamid, "cap", 0)
		else:
			es.keysetvalue("soccer_mod_admins", steamid, "cap", 1)
	elif choice == 5:
		if int(es.keygetvalue("soccer_mod_admins", steamid, "referee")) == 1:
			es.keysetvalue("soccer_mod_admins", steamid, "referee", 0)
		else:
			es.keysetvalue("soccer_mod_admins", steamid, "referee", 1)
	elif choice == 6:
		if int(es.keygetvalue("soccer_mod_admins", steamid, "training")) == 1:
			es.keysetvalue("soccer_mod_admins", steamid, "training", 0)
		else:
			es.keysetvalue("soccer_mod_admins", steamid, "training", 1)
	elif choice == 7:
		if int(es.keygetvalue("soccer_mod_admins", steamid, "settings")) == 1:
			es.keysetvalue("soccer_mod_admins", steamid, "settings", 0)
		else:
			es.keysetvalue("soccer_mod_admins", steamid, "settings", 1)
	elif choice == 8:
		if int(es.keygetvalue("soccer_mod_admins", steamid, "manager")) == 1:
			es.keysetvalue("soccer_mod_admins", steamid, "manager", 0)
		else:
			es.keysetvalue("soccer_mod_admins", steamid, "manager", 1)

	es.keygroupsave("soccer_mod_admins", "soccer_mod")

	name = "sm_popup_%s" % (userid)
	create_popup_edit(name, steamid)
	popuplib.send(name, userid)

# ******************** Remove admin ********************
def select_remove_admin(userid, choice, popupid):
	name = "sm_keymenu_%s" % (userid)
	if keymenulib.exists(name):
		keymenulib.delete(name)

	tokens = {}
	player = playerlib.getPlayer(userid)

	keymenu = keymenulib.create(name, "target", remove_admin, "soccer_mod_admins", "#keyvalue name", "#key", messages("remove_admin", tokens, player.get("lang")))
	keymenu.backmenu("sm_popup_admin_manager")
	keymenulib.send(name, userid)

def remove_admin(userid, choice, keymenuname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	number = 0
	for admin in keyvalues.getKeyGroup("soccer_mod_admins"):
		number += 1

	if number > 1:
		exists = es.exists("key", "soccer_mod_admins", choice)
		if exists == 1:
			es.keydelete("soccer_mod_admins", choice)
			es.keygroupsave("soccer_mod_admins", "soccer_mod")

			tokens["name"] = es.keygetvalue("soccer_mod_admins", choice, "name")
			es.tell(userid, "#green", messages("admin_removed", tokens, player.get("lang")))
		else:
			tokens["name"] = choice
			es.tell(userid, "#green", messages("admin_no_exist", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("1_admin", tokens, player.get("lang")))

	popuplib.send("sm_popup_admin_manager", userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	for player in playerlib.getPlayerList("#human"):
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def clear_key(userid, steamid):
	es.keydelete("sm_keygroup_set", steamid)
	popuplib.send("sm_popup_admin_manager", userid)

# ******************** Unload ********************
def unload():
	es.keygroupdelete("soccer_mod_admins")
	es.keygroupdelete("soccer_mod_maps")

	es.addons.unregisterSayFilter(sayFilter)
	popuplib.delete("sm_popup_admin_manager")