﻿import es
import gamethread
import langlib
import playerlib
import popuplib

common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/referee/messages_referee.ini")

# ******************** Load ********************
def load():
	create_popup()

	if es.ServerVar("sm_module_referee_warn_on") == 1:
		es.load("soccer_mod_2010/referee/warn")

	if es.ServerVar("sm_module_referee_punish_on") == 1:
		es.load("soccer_mod_2010/referee/punish")

# ******************** Events ********************
def es_map_start(event_var):
	if es.exists("keygroup", "soccer_mod_yellow_card") == 1:
		es.keygroupdelete("soccer_mod_yellow_card")

	if es.exists("keygroup", "soccer_mod_red_card") == 1:
		es.keygroupdelete("soccer_mod_red_card")

def player_spawn(event_var):
	if es.ServerVar("soccer_mod_allowed") == 1:
		if es.exists("key", "soccer_mod_red_card", event_var["es_steamid"]) == 1:
			change_team(event_var["userid"])

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/referee/popup_admin_referee.ini")

	popup = popuplib.create("sm_popup_admin_referee")

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")

	number = 1

	if es.ServerVar("sm_module_referee_warn_on") == 1:
		popup.addline("->%s. %s" % (number, text("warn")))
		popup.submenu(number, "sm_popup_admin_referee_warn")
		number += 1

	popup.addline("->%s. %s" % (number, text("yellow")))
	popup.select(number, yellow)
	number += 1

	popup.addline("->%s. %s" % (number, text("red")))
	popup.select(number, red)
	number += 1

	popup.addline("->%s. %s" % (number, text("clear")))
	popup.select(number, clear_cards)
	number += 1

	if es.ServerVar("sm_module_referee_punish_on") == 1:
		popup.addline("->%s. %s" % (number, text("punish")))
		popup.submenu(number, "sm_popup_admin_referee_punish")
		number += 1

	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	while number < 9:
		popup.submenu(number, "sm_popup_admin_referee")
		number += 1

	popup.submenu(9, "sm_popup_admin")

# ******************** Popup choices ********************
def yellow(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	create_player_menu(name, messages("select_player_yellow"), "#human", "sm_popup_admin_referee", "yellow")

	popuplib.send(name, userid)

def red(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	name = "sm_popup_%s" % (userid)
	create_player_menu(name, messages("select_player_red"), "#human", "sm_popup_admin_referee", "red")

	popuplib.send(name, userid)

def clear_cards(userid, choice, popupid):
	if es.exists("keygroup", "soccer_mod_yellow_card") == 1:
		es.keygroupdelete("soccer_mod_yellow_card")

	if es.exists("keygroup", "soccer_mod_red_card") == 1:
		es.keygroupdelete("soccer_mod_red_card")

	tokens = {}
	tokens["name"] = es.getplayername(userid)
	lang_msg("clear", tokens)

	popuplib.send("sm_popup_admin_referee", userid)

# ******************** Player menu choices ********************
def yellow_choice(userid, choice, popupname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("userid", choice) == 1:
		steamid = es.getplayersteamid(choice)
		if es.exists("key", "soccer_mod_red_card", steamid) == 0:
			if es.exists("keygroup", "soccer_mod_yellow_card") == 0:
				es.keygroupcreate("soccer_mod_yellow_card")

			if es.exists("key", "soccer_mod_yellow_card", steamid) == 0:
				es.keycreate("soccer_mod_yellow_card", steamid)
			else:
				if es.exists("keygroup", "soccer_mod_red_card") == 0:
					es.keygroupcreate("soccer_mod_red_card")

				es.keycreate("soccer_mod_red_card", steamid)

			tokens["name"] = player.name
			tokens["target"] = es.getplayername(choice)

			if es.exists("key", "soccer_mod_red_card", steamid) == 0:
				es.cexec_all("playgamesound", es.ServerVar("sm_referee_sound_whistle"))

				lang_msg("yellow_given", tokens)
			else:
				play_sound(es.ServerVar("sm_referee_sound_whistle"))
				gamethread.delayed(0.5, play_sound, (es.ServerVar("sm_referee_sound_red_card")))

				gamethread.delayed(6, change_team, (choice))

				lang_msg("2nd_yellow_given", tokens)
		else:
			es.tell(userid, "#green", messages("already_red", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_player_found", tokens, player.get("lang")))

	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popuplib.send("sm_popup_admin_referee", userid)

def red_choice(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("userid", choice) == 1:
		steamid = es.getplayersteamid(choice)
		if es.exists("key", "soccer_mod_red_card", steamid) == 0:
			if es.exists("keygroup", "soccer_mod_red_card") == 0:
				es.keygroupcreate("soccer_mod_red_card")

			es.keycreate("soccer_mod_red_card", steamid)

			play_sound(es.ServerVar("sm_referee_sound_whistle"))
			gamethread.delayed(0.5, play_sound, (es.ServerVar("sm_referee_sound_red_card")))

			gamethread.delayed(6, change_team, (choice))

			tokens["name"] = player.name
			tokens["target"] = es.getplayername(choice)
			lang_msg("red_given", tokens)
		else:
			es.tell(userid, "#green", messages("already_red", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_player_found", tokens, player.get("lang")))

	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popuplib.send("sm_popup_admin_referee", userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	for player in playerlib.getPlayerList("#human"):
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def play_sound(sound):
	es.cexec_all("playgamesound", sound)

def change_team(userid):
	player = playerlib.getPlayer(userid)
	if player.team > 1:
		es.server.queuecmd("es_changeteam %s 1" % (userid))

def create_player_menu(name, title, users, cancelmenu, block):
	if block == "yellow":
		myPopup = popuplib.easymenu(name, None, yellow_choice)
	elif block == "red":
		myPopup = popuplib.easymenu(name, None, red_choice)
	myPopup.settitle(title)

	for player in playerlib.getPlayerList(users):
		myPopup.addoption(player.userid, player.name)

	myPopup.submenu(10, cancelmenu)

# ******************** Unload ********************
def unload():
	if es.exists("keygroup", "soccer_mod_yellow_card") == 1:
		es.keygroupdelete("soccer_mod_yellow_card")

	if es.exists("keygroup", "soccer_mod_red_card") == 1:
		es.keygroupdelete("soccer_mod_red_card")

	popuplib.delete("sm_popup_admin_referee")

	if es.ServerVar("sm_module_referee_warn_on") == 1:
		es.unload("soccer_mod_2010/referee/warn")

	if es.ServerVar("sm_module_referee_punish_on") == 1:
		es.unload("soccer_mod_2010/referee/punish")