﻿import es
import langlib
import playerlib
import popuplib

popup = popuplib.create("sm_popup_admin_settings_match_time")

texts = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/settings/popup_admin_settings_match_time.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/settings/messages_settings_match_time.ini")

# ******************** Load ********************
def load():
	es.set("sm_match_number_periods", int(es.keygetvalue("soccer_mod_settings", "match", "periods")))
	es.set("sm_match_restart_length", int(es.keygetvalue("soccer_mod_settings", "match", "restart_length")))
	es.set("sm_match_period_length", int(es.keygetvalue("soccer_mod_settings", "match", "period_length")))
	es.set("sm_match_period_break_length", int(es.keygetvalue("soccer_mod_settings", "match", "period_break_length")))

	create_popup()

	es.addons.registerSayFilter(sayFilter)

# ******************** Create popup ********************
def create_popup():
	common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")

	popup.addline("SOCCER MOD %s" % (texts("title")))
	popup.addline(" ")
	popup.addline("->1. %s: %s" % (texts("periods"), es.ServerVar("sm_match_number_periods")))
	popup.addline("->2. %s: %s" % (texts("restart_length"), es.ServerVar("sm_match_restart_length")))
	popup.addline("->3. %s: %s" % (texts("period_length"), es.ServerVar("sm_match_period_length")))
	popup.addline("->4. %s: %s" % (texts("period_break_length"), es.ServerVar("sm_match_period_break_length")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	popup.select(1, change_time)
	popup.select(2, change_time)
	popup.select(3, change_time)
	popup.select(4, change_time)
	popup.submenu(5, "sm_popup_admin_settings_match_time")
	popup.submenu(6, "sm_popup_admin_settings_match_time")
	popup.submenu(7, "sm_popup_admin_settings_match_time")
	popup.submenu(8, "sm_popup_admin_settings_match_time")
	popup.submenu(9, "sm_popup_admin_settings_match")

# ******************** Popup choices ********************
def change_time(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("match") == 0:
		steamid = es.getplayersteamid(userid)
		if es.exists("key", "sm_keygroup_set", steamid) == 0:
			es.keycreate("sm_keygroup_set", steamid)

		if choice == 1:
			es.keysetvalue("sm_keygroup_set", steamid, "setting_type", "settings_match_time_periods")
			es.tell(userid, "#green", messages("set_periods_message", tokens, player.get("lang")))
		elif choice == 2:
			es.keysetvalue("sm_keygroup_set", steamid, "setting_type", "settings_match_time_restart_length")
			es.tell(userid, "#green", messages("set_restart_length_message", tokens, player.get("lang")))
		elif choice == 3:
			es.keysetvalue("sm_keygroup_set", steamid, "setting_type", "settings_match_time_period_length")
			es.tell(userid, "#green", messages("set_period_length_message", tokens, player.get("lang")))
		elif choice == 4:
			es.keysetvalue("sm_keygroup_set", steamid, "setting_type", "settings_match_time_period_break_length")
			es.tell(userid, "#green", messages("set_period_break_length_message", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_time_match", tokens, player.get("lang")))
		popuplib.send("sm_popup_admin_settings_match_time", userid)

# ******************** Events ********************
def sayFilter(userid, text, teamonly):
	steamid = es.getplayersteamid(userid)

	if es.exists("key", "sm_keygroup_set", steamid) == 1:
		text = text.strip('"')
		type = es.keygetvalue("sm_keygroup_set", steamid, "setting_type")
		if type == "settings_match_time_periods":
			set_value(userid, text, "set_periods_message", 1, 10, "sm_match_number_periods", 1, "periods", "set_periods")
			return (0, None, 0)
		elif type == "settings_match_time_restart_length":
			set_value(userid, text, "set_restart_length_message", 1, 60, "sm_match_restart_length", 2, "restart_length", "set_restart_length")
			return (0, None, 0)
		elif type == "settings_match_time_period_length":
			set_value(userid, text, "set_period_length_message", 1, 10000, "sm_match_period_length", 3, "period_length", "set_period_length")
			return (0, None, 0)
		elif type == "settings_match_time_period_break_length":
			set_value(userid, text, "set_period_break_length_message", 1, 10000, "sm_match_period_break_length", 4, "period_break_length", "set_period_break_length")
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

# ******************** Functions ********************
def lang_msg(text, tokens):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def set_value(userid, text, error_msg, min, max, cvar, number, keyvalue, lang):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if text != "!cancel":
		error = messages(error_msg, tokens, player.get("lang"))
		try:
			temp_value = float(text)
			value = int(round(temp_value, 0))
			if value >= min:
				if value <= max:
					es.set(cvar, value)

					popup.modline((number + 2), "->%s. %s: %s" % (number, texts(keyvalue), value))

					es.keysetvalue("soccer_mod_settings", "match", keyvalue, value)
					es.keygroupsave("soccer_mod_settings", "soccer_mod")

					tokens["name"] = player.name
					tokens["value"] = value
					lang_msg(lang, tokens)

					clear_key(userid, player.steamid)
				else:
					es.tell(userid, "#green", error)
			else:
				es.tell(userid, "#green", error)
		except ValueError:
			es.tell(userid, "#green", error)
	else:
		clear_key(userid, player.steamid)

def clear_key(userid, steamid):
	es.keydelete("sm_keygroup_set", steamid)
	popuplib.send("sm_popup_admin_settings_match_time", userid)

# ******************** Unload ********************
def unload():
	popuplib.delete("sm_popup_admin_settings_match_time")
	es.addons.unregisterSayFilter(sayFilter)