﻿import es
import langlib
import os
import playerlib
import popuplib

popup = popuplib.create("sm_popup_admin_settings_player")

texts = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/settings/popup_admin_settings_player.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/settings/messages_settings_player.ini")

# ******************** Load ********************
def load():
	es.set("sm_player_god_mode_on", int(es.keygetvalue("soccer_mod_settings", "player", "god_mode")))
	es.set("sm_player_hurt_sounds_on", int(es.keygetvalue("soccer_mod_settings", "player", "hurt_sounds")))
	es.set("sm_player_respawn_enabled", int(es.keygetvalue("soccer_mod_settings", "player", "respawn_enabled")))
	es.set("sm_player_respawn_length", int(es.keygetvalue("soccer_mod_settings", "player", "respawn_length")))

	create_popup()

	es.addons.registerSayFilter(sayFilter)

# ******************** Create popup ********************
def create_popup():
	common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")

	popup.addline("SOCCER MOD %s" % (texts("title")))
	popup.addline(" ")

	add_line("sm_player_god_mode_on", 1, "god_mode")
	add_line("sm_player_hurt_sounds_on", 2, "hurt_sounds")
	add_line("sm_player_respawn_enabled", 3, "respawn_enabled")

	popup.addline("->4. %s: %s" % (texts("respawn_length"), es.ServerVar("sm_player_respawn_length")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	popup.select(1, change_setting)
	popup.select(2, change_setting)
	popup.select(3, change_setting)
	popup.select(4, respawn_length)
	popup.submenu(5, "sm_popup_admin_settings_player")
	popup.submenu(6, "sm_popup_admin_settings_player")
	popup.submenu(7, "sm_popup_admin_settings_player")
	popup.submenu(8, "sm_popup_admin_settings_player")
	popup.submenu(9, "sm_popup_admin_settings")

def add_line(cvar, number, lang):
	if es.ServerVar(cvar) == 1:
		value = texts("on")
	else:
		value = texts("off")

	line = "->%s. %s: %s" % (number, texts(lang), value)
	popup.addline(line)

# ******************** Popup choices ********************
def change_setting(userid, choice, popupid):
	if choice == 1:
		set_value(userid, "sm_player_god_mode_on", "god_mode", "god_mode", "set_god_mode", choice)
	elif choice == 2:
		set_value(userid, "sm_player_hurt_sounds_on", "hurt_sounds", "hurt_sounds", "set_hurt_sounds", choice)
	elif choice == 3:
		set_value(userid, "sm_player_respawn_enabled", "respawn_enabled", "respawn_enabled", "set_respawn_enabled", choice)

def respawn_length(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
		es.keycreate("sm_keygroup_set", player.steamid)

	es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "settings_player_respawn_length")

	es.tell(userid, "#green", messages("set_respawn_length_message", tokens, player.get("lang")))

# ******************** Events ********************
def sayFilter(userid, text, teamonly):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 1:
		text = text.strip('"')
		type = es.keygetvalue("sm_keygroup_set", player.steamid, "setting_type")
		if type == "settings_player_respawn_length":
			if text != "!cancel":
				error = messages("set_respawn_length_message", tokens, player.get("lang"))
				try:
					temp_value = float(text)
					value = int(round(temp_value, 0))
					if value >= 1:
						if value <= 60:
							es.set("sm_player_respawn_length", value)

							popup.modline(6, "->4. %s: %s" % (texts("respawn_length"), value))

							es.keysetvalue("soccer_mod_settings", "player", "respawn_length", value)
							es.keygroupsave("soccer_mod_settings", "soccer_mod")

							tokens["name"] = player.name
							tokens["value"] = value
							lang_msg("set_respawn_length", tokens)

							clear_key(userid, player.steamid)
						else:
							es.tell(userid, "#green", error)
					else:
						es.tell(userid, "#green", error)
				except ValueError:
					es.tell(userid, "#green", error)
			else:
				clear_key(userid, player.steamid)
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

# ******************** Functions ********************
def set_value(userid, cvar, keyvalue, line, msg, number):
	tokens = {}
	tokens["name"] = es.getplayername(userid)

	if es.ServerVar(cvar) == 1:
		es.set(cvar, 0)
		es.keysetvalue("soccer_mod_settings", "player", keyvalue, 0)

		popup.modline((number + 2), "->%s. %s: %s" % (number, texts(line), texts("off")))

		lang_msg_on_off(msg, tokens, "off")
	else:
		es.set(cvar, 1)
		es.keysetvalue("soccer_mod_settings", "player", keyvalue, 1)

		popup.modline((number + 2), "->%s. %s: %s" % (number, texts(line), texts("on")))

		lang_msg_on_off(msg, tokens, "on")

	es.keygroupsave("soccer_mod_settings", "soccer_mod")

	popuplib.send("sm_popup_admin_settings_player", userid)

def lang_msg_on_off(text, tokens, on_off):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		tokens["value"] = messages(on_off, tokens, player.get("lang"))
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def lang_msg(text, tokens):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def clear_key(userid, steamid):
	es.keydelete("sm_keygroup_set", steamid)
	popuplib.send("sm_popup_admin_settings_player", userid)

# ******************** Unload ********************
def unload():
	popuplib.delete("sm_popup_admin_settings_player")
	es.addons.unregisterSayFilter(sayFilter)