﻿import es
import langlib
import playerlib
import popuplib

popup = popuplib.create("sm_popup_admin_settings_sprint")

texts = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/settings/popup_admin_settings_sprint.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/settings/messages_settings_sprint.ini")

# ******************** Load ********************
def load():
	es.set("sm_sprint_speed", float(es.keygetvalue("soccer_mod_settings", "sprint", "speed")))
	es.set("sm_sprint_length", int(es.keygetvalue("soccer_mod_settings", "sprint", "length")))
	es.set("sm_sprint_reset", int(es.keygetvalue("soccer_mod_settings", "sprint", "reset")))

	create_popup()

	es.addons.registerSayFilter(sayFilter)

# ******************** Create popup ********************
def create_popup():
	common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")

	popup.addline("SOCCER MOD %s" % (texts("title")))
	popup.addline(" ")
	popup.addline("->1. %s: %s" % (texts("speed"), es.ServerVar("sm_sprint_speed")))
	popup.addline("->2. %s: %s" % (texts("length"), es.ServerVar("sm_sprint_length")))
	popup.addline("->3. %s: %s" % (texts("reset"), es.ServerVar("sm_sprint_reset")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	popup.select(1, change_sprint)
	popup.select(2, change_sprint)
	popup.select(3, change_sprint)
	popup.submenu(4, "sm_popup_admin_settings_sprint")
	popup.submenu(5, "sm_popup_admin_settings_sprint")
	popup.submenu(6, "sm_popup_admin_settings_sprint")
	popup.submenu(7, "sm_popup_admin_settings_sprint")
	popup.submenu(8, "sm_popup_admin_settings_sprint")
	popup.submenu(9, "sm_popup_admin_settings")

# ******************** Popup choices ********************
def change_sprint(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
		es.keycreate("sm_keygroup_set", player.steamid)

	if choice == 1:
		es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "settings_sprint_speed")
		es.tell(userid, "#green", messages("set_sprint_speed_message", tokens, player.get("lang")))
	elif choice == 2:
		es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "settings_sprint_length")
		es.tell(userid, "#green", messages("set_sprint_length_message", tokens, player.get("lang")))
	elif choice == 3:
		es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "settings_sprint_reset")
		es.tell(userid, "#green", messages("set_sprint_reset_length_message", tokens, player.get("lang")))

# ******************** Events ********************
def sayFilter(userid, text, teamonly):
	steamid = es.getplayersteamid(userid)
	if es.exists("key", "sm_keygroup_set", steamid) == 1:
		text = text.strip('"')
		type = es.keygetvalue("sm_keygroup_set", steamid, "setting_type")
		if type == "settings_sprint_speed":
			set_value(userid, text, "set_sprint_speed_message", 2, 1, 10, "sm_sprint_speed", 1, "speed", "set_sprint_speed")
			return (0, None, 0)
		elif type == "settings_sprint_length":
			set_value(userid, text, "set_sprint_length_message", 0, 1, 10, "sm_sprint_length", 2, "length", "set_sprint_length")
			return (0, None, 0)
		elif type == "settings_sprint_reset":
			set_value(userid, text, "set_sprint_reset_length_message", 0, 1, 100, "sm_sprint_reset", 3, "reset", "set_sprint_reset_length")
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

def set_value(userid, text, error_msg, decimals, min, max, cvar, number, keyvalue, lang):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if text != "!cancel":
		error = messages(error_msg, tokens, player.get("lang"))
		try:
			temp_value = float(text)
			if decimals < 1:
				value = int(round(temp_value, 0))
			else:
				value = float(round(temp_value, decimals))

			if value >= min:
				if value <= max:
					es.set(cvar, value)

					popup.modline((number +2), "->%s. %s: %s" % (number, texts(keyvalue), value))

					es.keysetvalue("soccer_mod_settings", "sprint", keyvalue, value)
					es.keygroupsave("soccer_mod_settings", "soccer_mod")

					tokens["name"] = player.name
					tokens["value"] = value
					lang_msg(lang, tokens)

					clear_key(userid, player.steamid)
				else:
					es.tell(userid, "#green", error)
			else:
				es.tell(userid, "#green", error)
		except ValueError:
			es.tell(userid, "#green", error)
	else:
		clear_key(userid, player.steamid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def clear_key(userid, steamid):
	es.keydelete("sm_keygroup_set", steamid)
	popuplib.send("sm_popup_admin_settings_sprint", userid)

# ******************** Unload ********************
def unload():
	popuplib.delete("sm_popup_admin_settings_sprint")
	es.addons.unregisterSayFilter(sayFilter)