﻿import es
import gamethread
import langlib
import playerlib
import popuplib
import random
import repeat
import vecmath

popup_name = "sm_popup_admin_training_cannon"
popup = popuplib.create(popup_name)

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2010/language/"
common = langlib.Strings(lang_dir + "common.ini")
messages = langlib.Strings(lang_dir + "training/messages_training_cannon.ini")
texts = langlib.Strings(lang_dir + "training/popup_admin_training_cannon.ini")

# ******************** Load ********************
def load():
	es.set("sm_training_cannon_on", 0)
	es.set("sm_training_randomness", 1)
	es.set("sm_training_fire_rate", 2.5)
	es.set("sm_training_height", 1)
	es.set("sm_training_power", 10000.0)

	create_popup()

	sm_training_cannon = repeat.create("cannon", shoot, ())

	es.addons.registerSayFilter(sayFilter)

# ******************** Events ********************
def round_start(event_var):
	if es.ServerVar("soccer_mod_allowed") == 1:
		es.set("sm_training_ballid", es.getentityindex("func_physbox"))

def player_disconnect(event_var):
	if es.ServerVar("soccer_mod_allowed") == 1:
		if len(playerlib.getPlayerList("#human")) < 1:
			sm_training_cannon = repeat.find("cannon")

			if sm_training_cannon.status() > 1:
				sm_training_cannon.stop()
				es.set("sm_training_cannon_on", 0)

def sayFilter(userid, text, teamonly):
	steamid = es.getplayersteamid(userid)

	if es.exists("key", "sm_keygroup_set", steamid) == 1:
		text = text.strip('"')
		type = es.keygetvalue("sm_keygroup_set", steamid, "setting_type")
		if type == "training_randomness":
			set_cannon_value(userid, text, "randomness", 0, 1, 500, 5)
			return (0, None, 0)
		elif type == "training_fire_rate":
			set_cannon_value(userid, text, "fire_rate", 1, 0.5, 10, 6)
			return (0, None, 0)
		elif type == "training_height":
			set_cannon_value(userid, text, "height", 0, 1, 500, 7)
			return (0, None, 0)
		elif type == "training_power":
			set_cannon_value(userid, text, "power", 3, 0.001, 10000, 8)
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

# ******************** Create popup ********************
def create_popup():
	popup.addline("SOCCER MOD %s" % (texts("title")))
	popup.addline(" ")
	popup.addline("->1. %s" % (texts("position")))
	popup.addline("->2. %s" % (texts("aim")))
	popup.addline("->3. %s" % (texts("on")))
	popup.addline("->4. %s" % (texts("off")))
	popup.addline("->5. %s: %s" % (texts("randomness"), es.ServerVar("sm_training_randomness")))
	popup.addline("->6. %s: %s" % (texts("fire_rate"), es.ServerVar("sm_training_fire_rate")))
	popup.addline("->7. %s: %s" % (texts("height"), es.ServerVar("sm_training_height")))
	popup.addline("->8. %s: %s" % (texts("power"), es.ServerVar("sm_training_power")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	popup.select(1, change_position)
	popup.select(2, change_position)
	popup.select(3, cannon_on)
	popup.select(4, cannon_off)
	popup.select(5, change_cannon)
	popup.select(6, change_cannon)
	popup.select(7, change_cannon)
	popup.select(8, change_cannon)
	popup.submenu(9, "sm_popup_admin_training")

# ******************** Popup choices ********************
def change_position(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("match") == 0:
		tokens["name"] = player.name

		if choice == 1:
			es.set("cannon_x", 0)
			es.set("cannon_y", 0)
			es.set("cannon_z", 0)

			es.server.queuecmd("playerget viewcoord %s cannon_x cannon_y cannon_z" % (userid))

			gamethread.delayed(0.01, show_position)

			lang_msg("position", tokens)

		elif choice == 2:
			es.set("cannon_aim_x", 0)
			es.set("cannon_aim_y", 0)
			es.set("cannon_aim_z", 0)

			es.server.queuecmd("playerget viewcoord %s cannon_aim_x cannon_aim_y cannon_aim_z" % (userid))

			gamethread.delayed(0.01, show_aim_position)

			lang_msg("aim_position", tokens)
	else:
		if choice == 1:
			es.tell(userid, "#green", messages("no_postion_match", tokens, player.get("lang")))
		elif choice == 2:
			es.tell(userid, "#green", messages("no_aim_postion_match", tokens, player.get("lang")))

	popuplib.send(popup_name, userid)

def cannon_on(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("match") == 0:
		if es.ServerVar("sm_training_ballid") > 0:
			sm_training_cannon = repeat.find("cannon")

			if sm_training_cannon.status() == 1:
				es.set("sm_training_cannon_on", 1)

				shoot()

				sm_training_cannon.start(float(es.ServerVar("sm_training_fire_rate")), 0)

				tokens["name"] = player.name
				lang_msg("on", tokens)
			else:
				es.tell(userid, "#green", messages("already_on", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("no_ball", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_on_match", tokens, player.get("lang")))

	popuplib.send(popup_name, userid)

def cannon_off(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	sm_training_cannon = repeat.find("cannon")

	if sm_training_cannon.status() > 1:
		sm_training_cannon.stop()

		es.set("sm_training_cannon_on", 0)

		tokens["name"] = player.name
		lang_msg("off", tokens)
	else:
		es.tell(userid, "#green", messages("already_off", tokens, player.get("lang")))

	popuplib.send(popup_name, userid)

def change_cannon(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("match") == 0:
		if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
			es.keycreate("sm_keygroup_set", player.steamid)

		if choice == 5:
			es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "training_randomness")
			es.tell(userid, "#green", messages("set_randomness_message", tokens, player.get("lang")))
		elif choice == 6:
			es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "training_fire_rate")
			es.tell(userid, "#green", messages("set_fire_rate_message", tokens, player.get("lang")))
		elif choice == 7:
			es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "training_height")
			es.tell(userid, "#green", messages("set_height_message", tokens, player.get("lang")))
		elif choice == 8:
			es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "training_power")
			es.tell(userid, "#green", messages("set_power_message", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_settings_match", tokens, player.get("lang")))
		popuplib.send(popup_name, userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	for player in playerlib.getPlayerList("#human"):
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def show_position():
	show_lines(es.ServerVar("cannon_x"), es.ServerVar("cannon_y"), es.ServerVar("cannon_z"))

def show_aim_position():
	show_lines(es.ServerVar("cannon_aim_x"), es.ServerVar("cannon_aim_y"), es.ServerVar("cannon_aim_z"))

def show_lines(x, y, z):
	model = es.precachemodel("sprites/crystal_beam1.vmt")

	pos1 = "%s,%s,%s" % ((x - 25), y, z)
	pos2 = "%s,%s,%s" % ((x + 25), y, z)
	es.server.queuecmd("es_effect beam %s %s %s %s 0 0 5 5 5 0 1 255 0 0 255 5" % (pos1, pos2, model, model))

	pos1 = "%s,%s,%s" % (x, (y - 25), z)
	pos2 = "%s,%s,%s" % (x, (y + 25), z)
	es.server.queuecmd("es_effect beam %s %s %s %s 0 0 5 5 5 0 1 255 0 0 255 5" % (pos1, pos2, model, model))

	pos1 = "%s,%s,%s" % (x, y, (z - 25))
	pos2 = "%s,%s,%s" % (x, y, (z + 25))
	es.server.queuecmd("es_effect beam %s %s %s %s 0 0 5 5 5 0 1 255 0 0 255 5" % (pos1, pos2, model, model))

def shoot():
	x = es.ServerVar("cannon_x")
	y = es.ServerVar("cannon_y")
	z = es.ServerVar("cannon_z")

	z += 15
	z += int(es.ServerVar("sm_training_height"))

	players = es.getUseridList()
	length = len(players)
	if length > 0:
		es.server.queuecmd("es_xfire %s func_physbox wake" % (players[random.randint(0, length - 1)]))

	es.server.queuecmd("es_xphysics active teleport %s %s,%s,%s" % (es.ServerVar("sm_training_ballid"), x, y, z))
	gamethread.delayed(0.1, push)

def push():
	aim_x = es.ServerVar("cannon_aim_x")
	aim_y = es.ServerVar("cannon_aim_y")
	aim_z = es.ServerVar("cannon_aim_z")

	randomness = int(es.ServerVar("sm_training_randomness"))
	if randomness > 0:
		aim_x = random.uniform(aim_x - randomness, aim_x + randomness)
		aim_y = random.uniform(aim_y - randomness, aim_y + randomness)
		aim_z = random.uniform(aim_z - randomness, aim_z + randomness)

	vector1 = vecmath.vector([aim_x, aim_y, aim_z])

	x = es.ServerVar("cannon_x")
	y = es.ServerVar("cannon_y")
	z = es.ServerVar("cannon_z")
	vector2 = vecmath.vector([x, y, z])

	es.set("sm_training_cannon_aim", (vector1 - vector2) * float(es.ServerVar("sm_training_power")))

	es.server.queuecmd("es_xphysics active setvelocity %s %s" % (es.ServerVar("sm_training_ballid"), es.ServerVar("sm_training_cannon_aim")))

def set_cannon_value(userid, text, msg, decimals, min, max, number):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if text != "!cancel":
		error = messages("set_%s_message" % (msg), tokens, player.get("lang"))
		try:
			temp_value = float(text)
			if decimals < 1:
				value = int(round(temp_value, decimals))
			else:
				value = round(temp_value, decimals)
			if value >= min:
				if value <= max:
					es.set("sm_training_%s" % (msg), value)

					popup.modline((number + 2), "->%s. %s: %s" % (number, texts(msg), value))

					if msg == "fire_rate":
						sm_training_cannon = repeat.find("cannon")

						if sm_training_cannon.status() > 1:
							sm_training_cannon.stop()
							shoot()
							sm_training_cannon.start(float(es.ServerVar("sm_training_fire_rate")), 0)

					tokens["name"] = player.name
					tokens["value"] = value
					lang_msg("set_%s" % (msg), tokens)

					es.keydelete("sm_keygroup_set", player.steamid)
					popuplib.send(popup_name, userid)
				else:
					es.tell(userid, "#green", error)
			else:
				es.tell(userid, "#green", error)
		except ValueError:
			es.tell(userid, "#green", error)
	else:
		es.keydelete("sm_keygroup_set", player.steamid)
		popuplib.send(popup_name, userid)

# ******************** Unload ********************
def unload():
	repeat.delete("cannon")

	popuplib.delete(popup_name)

	es.addons.unregisterSayFilter(sayFilter)